@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-02-26'; # DATE
-our $VERSION = '0.87'; # VERSION
+our $DATE = '2015-02-27'; # DATE
+our $VERSION = '0.88'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1142,7 +1142,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 0.87 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-26.
+This document describes version 0.88 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-27.
 
 =head1 DESCRIPTION
 
@@ -1389,9 +1389,9 @@ Configuration can be used to set function arguments.
 
 Configuration is currently in the L<IOD> (basically INI) format.
 
-By default these paths are searched: C<$HOME/$prog_name.conf>,
-C</etc/$prog_name.conf>. The location can be customized from command-line option
-C<--config-path>.
+By default these paths are searched: C<$HOME/.config/$prog_name.conf>,
+C<$HOME/$prog_name.conf>, C</etc/$prog_name.conf>. The location can be
+customized from command-line option C<--config-path>.
 
 All existing configuration files will be read in order.
 
@@ -1749,8 +1749,9 @@ Whether to read configuration files.
 =head2 config_dirs => array of str
 
 Which directories to look for configuration file. The default is to look at the
-system location and then per-user home directory. On Unix, it's C<< ["/etc",
-$ENV{HOME}] >>.
+user's home and then system location. On Unix, it's C<< [ "$ENV{HOME}/.config",
+$ENV{HOME}, "/etc"] >>. If $ENV{HOME} is empty, getpwuid() is used to get home
+directory entry.
 
 =head2 config_filename => str
 
