@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2015-02-26'; # DATE
-our $VERSION = '0.87'; # VERSION
+our $DATE = '2015-02-27'; # DATE
+our $VERSION = '0.88'; # VERSION
 
 use 5.010;
 use strict;
@@ -20,7 +20,16 @@ sub get_default_config_dirs {
         require File::HomeDir;
         push @dirs, File::HomeDir->my_home;
     } else {
-        push @dirs, $ENV{HOME};
+        my $home = $ENV{HOME};
+        unless ($home) {
+            # sometimes HOME is not defined, in that case we'll use getpwuid()
+            my @pw = getpwuid($>);
+            $home = $pw[7] if @pw;
+        }
+        if ($home) {
+            push @dirs, "$home/.config";
+            push @dirs, $home;
+        }
         push @dirs, "/etc";
     }
     [grep {defined} @dirs];
@@ -143,7 +152,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 0.87 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-26.
+This document describes version 0.88 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-02-27.
 
 =head1 FUNCTIONS
 
